@@ -188,4 +188,15 @@ class Graph(object):
 
     def __iter__(self):
         for triple in self.triples:
-            yield triple
\ No newline at end of file
+            yield triple
+
+    def __str__(self):
+        result = str()
+        result += '\n' + self.id + ':'
+        for s in self.to_dict():
+            result += '\n - ' + str(s) + ':'
+            for p in self.dictionary[s]:
+                result += '\n  - ' + str(p)
+                for o in self.dictionary[s][p]:
+                    result += '\n   - ' + str(o)
+        return result
\ No newline at end of file
